@@ -29,7 +29,10 @@ class Point3d:
         self._z = value
 
     def reverse(self):
-        return Point(-self._x, -self._y, -self._z)
+        return Point3d(-self._x, -self._y, -self._z)
+
+    def is_zero(self):
+        return abs(self.x - 0.0) < 1e-3 and abs(self.y - 0.0) < 1e-3 and abs(self.z - 0.0) < 1e-3
 
     def __repr__(self):
         return f"Point - ({self._x}, {self._y}, {self._z})"
